@@ -1,10 +1,4 @@
-from qtstrap import (
-    QtCore,
-    BaseMainWindow,
-    QPushButton,
-    QLabel,
-    CVBoxLayout,
-)
+from qtstrap import *
 
 
 class MainWindow(BaseMainWindow):
@@ -25,4 +19,21 @@ def test_base_window_startup(qtbot):
     assert window.label.text() == '^^^^^^^'
 
     qtbot.mouseClick(window.button, QtCore.Qt.LeftButton)
-    assert window.label.text() == 'clicked'
\ No newline at end of file
+    assert window.label.text() == 'clicked'
+
+
+# def test_base_window_settings(qtbot):
+#     window = MainWindow()
+
+#     qtbot.addWidget(window)
+#     assert window.geometry() == QRect(0, 0, 640, 480)
+
+#     window.setGeometry(100, 100, 640, 480)
+#     assert window.geometry() == QRect(100, 100, 640, 480)
+
+#     window.close()
+    
+#     window = MainWindow()
+    
+#     qtbot.addWidget(window)
+#     assert window.geometry() == QRect(100, 100, 640, 480)
\ No newline at end of file
